TurboGears Profiler
===================

TurboGears Profiler (tg-profiler) is a TurboGears 1 extension aiming to provide
better profiling options to TG applications. It focus on lightweight profiling
which can be used in production environment, with very little overhead to the application.

TurboGears Profiler is still a work in progress, and util the release of version 1.0.0, the API can
be hardly changed, without backwards-compatibility.

Installation
============

.. code-block:: bash

    $ pip install tg-profiler

Features 
========

* Memory Snapshot saving as a CSV file

License
=======

Licensed under the MIT license

----

MIT License (MIT)
Copyright © 2015 Sthima, http://www.sthima.com.br

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

